@@ -18,19 +18,21 @@ pub(super) fn is_enabled() -> bool {
 #[inline]
 pub(super) fn disable() {
     unsafe {
+        // Do not use `nomem` because prevent subsequent memory accesses from being reordered before interrupts are disabled.
         #[cfg(not(portable_atomic_no_asm))]
-        asm!("cli", options(nomem, nostack));
+        asm!("cli", options(nostack));
         #[cfg(portable_atomic_no_asm)]
-        llvm_asm!("cli" :::: "volatile");
+        llvm_asm!("cli" ::: "memory" : "volatile");
     }
 }
 
 #[inline]
 pub(super) unsafe fn enable() {
     unsafe {
+        // Do not use `nomem` because prevent preceding memory accesses from being reordered after interrupts are enabled.
         #[cfg(not(portable_atomic_no_asm))]
-        asm!("sei", options(nomem, nostack));
+        asm!("sei", options(nostack));
         #[cfg(portable_atomic_no_asm)]
-        llvm_asm!("sei" :::: "volatile");
+        llvm_asm!("sei" ::: "memory" : "volatile");
     }
 }
