@@ -15,17 +15,19 @@ pub(super) fn is_enabled() -> bool {
 #[inline]
 pub(super) fn disable() {
     unsafe {
+        // Do not use `nomem` because prevent subsequent memory accesses from being reordered before interrupts are disabled.
         // TODO(taiki-e): we can probably add preserves_flags here, because
         // the rules of preserves_flags do not include the interrupt flag.
-        asm!("csrci mstatus, 0x8", options(nomem, nostack));
+        asm!("csrci mstatus, 0x8", options(nostack));
     }
 }
 
 #[inline]
 pub(super) unsafe fn enable() {
     unsafe {
+        // Do not use `nomem` because prevent preceding memory accesses from being reordered after interrupts are enabled.
         // TODO(taiki-e): we can probably add preserves_flags here, because
         // the rules of preserves_flags do not include the interrupt flag.
-        asm!("csrsi mstatus, 0x8", options(nomem, nostack));
+        asm!("csrsi mstatus, 0x8", options(nostack));
     }
 }
