@@ -67,23 +67,20 @@ macro_rules! __test_atomic_int_load_store {
         use crossbeam_utils::thread;
         #[test]
         fn stress_load_store() {
-            #[cfg(miri)]
-            const N: usize = 500;
-            #[cfg(not(miri))]
-            const N: usize = 100000;
-            let threads = if cfg!(debug_assertions) { 2 } else { fastrand::usize(2..8) };
-            std::eprintln!("threads={}", threads);
+            let iterations = if cfg!(miri) { 500 } else { 25_000 };
+            let threads = if cfg!(debug_assertions) { 2 } else { fastrand::usize(2..=8) };
             let a = <$atomic_type>::new(0);
+            std::eprintln!("threads={}", threads);
             thread::scope(|s| {
                 for _ in 0..threads {
                     s.spawn(|_| {
-                        for _ in 0..N {
+                        for _ in 0..iterations {
                             let v = fastrand::$int_type(..);
                             a.store(v, rand_store_ordering());
                         }
                     });
                     s.spawn(|_| {
-                        for _ in 0..N {
+                        for _ in 0..iterations {
                             a.load(rand_load_ordering());
                         }
                     });
@@ -204,9 +201,9 @@ macro_rules! __test_atomic_int {
             test_compare_exchange_ordering(|success, failure| {
                 a.compare_exchange(5, 5, success, failure)
             });
-            assert_eq!(a.compare_exchange(5, 10, Ordering::Acquire, Ordering::Relaxed), Ok(5),);
+            assert_eq!(a.compare_exchange(5, 10, Ordering::Acquire, Ordering::Relaxed), Ok(5));
             assert_eq!(a.load(Ordering::Relaxed), 10);
-            assert_eq!(a.compare_exchange(6, 12, Ordering::SeqCst, Ordering::Acquire), Err(10),);
+            assert_eq!(a.compare_exchange(6, 12, Ordering::SeqCst, Ordering::Acquire), Err(10));
             assert_eq!(a.load(Ordering::Relaxed), 10);
         }
         #[test]
@@ -215,7 +212,7 @@ macro_rules! __test_atomic_int {
             test_compare_exchange_ordering(|success, failure| {
                 a.compare_exchange_weak(4, 4, success, failure)
             });
-            assert_eq!(a.compare_exchange_weak(6, 8, Ordering::SeqCst, Ordering::Acquire), Err(4),);
+            assert_eq!(a.compare_exchange_weak(6, 8, Ordering::SeqCst, Ordering::Acquire), Err(4));
             let mut old = a.load(Ordering::Relaxed);
             loop {
                 let new = old * 2;
@@ -377,28 +374,25 @@ macro_rules! __test_atomic_int {
         __test_atomic_int!($atomic_type, $int_type, single_thread);
         #[test]
         fn stress() {
-            #[cfg(miri)]
-            const N: usize = 500;
-            #[cfg(not(miri))]
-            const N: usize = 100000;
-            let threads = if cfg!(debug_assertions) { 2 } else { fastrand::usize(2..8) };
-            std::eprintln!("threads={}", threads);
+            let iterations = if cfg!(miri) { 500 } else { 25_000 };
+            let threads = if cfg!(debug_assertions) { 2 } else { fastrand::usize(2..=8) };
             let a = <$atomic_type>::new(0);
+            std::eprintln!("threads={}", threads);
             thread::scope(|s| {
                 for _ in 0..threads {
                     s.spawn(|_| {
-                        for _ in 0..N {
+                        for _ in 0..iterations {
                             let v = fastrand::$int_type(..);
                             a.store(v, rand_store_ordering());
                         }
                     });
                     s.spawn(|_| {
-                        for _ in 0..N {
+                        for _ in 0..iterations {
                             a.load(rand_load_ordering());
                         }
                     });
                     s.spawn(|_| {
-                        for i in 0..N {
+                        for i in 0..iterations {
                             let old = if i % 2 == 0 {
                                 fastrand::$int_type(..)
                             } else {
